@@ -1,7 +1,7 @@
 package Task::Dancer2;
 use strict;
 use warnings;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 1;
 
@@ -13,7 +13,7 @@ Task::Dancer2 - Dancer2... in a box!
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =head1 DESCRIPTION
 
@@ -59,7 +59,7 @@ tell us if any module that was temporarily disabled is working again.
 
 =item L<Dancer2::Logger::Console::Colored>
 
-=item L<Dancer::Logger::File::RotateLogs>
+=item L<Dancer2::Logger::File::RotateLogs>
 
 =item L<Dancer2::Logger::Syslog>
 
@@ -207,6 +207,10 @@ tell us if any module that was temporarily disabled is working again.
 
 Jason A. Crome C< cromedome AT cpan DOT org >
 
+=head1 CONTRIBUTORS
+
+Rory Zweistra
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-task-dancer at rt.cpan.org>,
